from setuptools import setup, find_packages
setup(name="edphelper",
      version="0.5",
      py_modules=["helper"],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)